@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic musical ornamentation
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -82,22 +82,22 @@ sub grace_note {
 
 
 sub turn {
-    my ($self, $duration, $pitch, $direction) = @_;
+    my ($self, $duration, $pitch, $offset) = @_;
 
-    $direction ||= 1;
+    $offset ||= 1;
 
     my ($above, $below);
 
     if ($self->scale_name eq 'chromatic') {
-        $above = Music::Note->new($pitch, 'ISO')->format('midinum') + 1;
+        $above = Music::Note->new($pitch, 'ISO')->format('midinum') + $offset;
         $above = Music::Note->new($above, 'midinum')->format('ISO');
-        $below = Music::Note->new($pitch, 'ISO')->format('midinum') - 1;
+        $below = Music::Note->new($pitch, 'ISO')->format('midinum') - $offset;
         $below = Music::Note->new($below, 'midinum')->format('ISO');
     }
     else {
         my $i = first_index { $_ eq $pitch } @{ $self->_scale };
-        $above = $self->_scale->[ $i + 1 ];
-        $below = $self->_scale->[ $i - 1 ];
+        $above = $self->_scale->[ $i + $offset ];
+        $below = $self->_scale->[ $i - $offset ];
     }
     print "Above/Below: $above / $below\n" if $self->verbose;
 
@@ -106,17 +106,7 @@ sub turn {
     print "Durations: $x, $z\n" if $self->verbose;
     $z = 'd' . $z;
 
-    my @turn;
-
-    if ($direction == 1) {
-        push @turn, [$z, $above], [$z, $pitch], [$z, $below], [$z, $pitch];
-    }
-    elsif ($direction == -1) {
-        push @turn, [$z, $below], [$z, $pitch], [$z, $above], [$z, $pitch];
-    }
-    else {
-        croak "Unknown turn direction: $direction";
-    }
+    my @turn = ([$z, $above], [$z, $pitch], [$z, $below], [$z, $pitch]);;
     print 'Turn: ', ddc(\@turn) if $self->verbose;
 
     return \@turn;
@@ -200,7 +190,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic musical ornamentati
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -272,12 +262,12 @@ have to do that bit.
 
 =head2 turn
 
-  $spec = $md->turn($duration, $pitch, $direction);
+  $spec = $md->turn($duration, $pitch, $offset);
 
 The note Above, the Principle note (the B<pitch>), the note Below, the
 Principle note again.
 
-The default B<direction> is C<1>, but if given as C<-1>, the turn is
+The default B<offset> is C<1>, but if given as C<-1>, the turn is
 "inverted" and goes: Below, Principle, Above, Principle.
 
 =head2 trill
